==> Amara-2.0a1.zip: Amara-2.0a1/test/xslt/test_avt.py <==
########################################################################
# test/xslt/test_avt.py
from amara.test import test_main
from amara.test.xpath.test_expressions import test_expression
from amara.xpath import datatypes
from amara.xslt import XsltError

class test_avt(test_expression):
    module_name = 'amara.xslt.expressions.avt'
    class_name = "avt_expression"
    evaluate_method = 'evaluate_as_string'
    return_type = datatypes.string
    test_cases = [
        ('', ''),
        ('Senatus{{populisque}}romae', 'Senatus{populisque}romae'),
        ('Senatus{{{"populisque}}"}romae', 'Senatus{populisque}}romae'),
        ('{"{literal}"}', '{literal}'),
        ('{"{literal"}', '{literal'),
        ('{"literal}"}', 'literal}'),
        ('{"{{literal}}"}', '{{literal}}'),
        ('{"{{literal"}', '{{literal'),
        ('{"literal}}"}', 'literal}}'),
        ('{{{"literal"}', '{literal'),
        ('{{-{"literal"}', '{-literal'),
        ('{"literal"}}}', 'literal}'),
        ('{"literal"}-}}', 'literal-}'),
        ('{"100"}% {100}% {90+10}% 100% {"%"}1{0}0 %100', '100% 100% 100% 100% %100 %100'),
        ]

    @classmethod
    def unpack_test_case(cls, source, expected=None, *extras):
        return (source,), expected, extras


class test_avt_errors(test_avt):
    test_cases = [
        ('{}',),                # no expression is error
        ('{-{{"literal"}',),    # '-{"literal"' is invalid Expr
        ('{"literal"}}-}',),    # '{"literal"} is expr; '}-}' is error
        ('{{node()}',),         # '{{node()' is literal, trailing '}' is error
        ('{node()}}',),         # '{node()}' is expr; trailing '}' is error
        ('(id(@ref)/title}',),  # missing leading '{'
        ('{(id(@ref)/title',),  # missing trailing '{'
        ]

    @classmethod
    def new_test_method(cls, expected, factory, args):
        def test_method(self):
            self.assertRaises(XsltError, factory, *args)
        return test_method


if __name__ == '__main__':
    test_main()

==> Amara-2.0.0a6.zip: Amara-2.0.0a6/test/xslt/test_avt.py <==
########################################################################
# test/xslt/test_avt.py
from amara.test.xpath.test_expressions import DOC
from amara.xpath import datatypes, context
from amara.xslt import XsltError

from amara.xslt.expressions.avt import avt_expression

DEFAULT_CONTEXT = context(DOC, 1, 1)

def test_avt():
    for arg, expected in (
        ('', ''),
        ('Senatus{{populisque}}romae', 'Senatus{populisque}romae'),
        ('Senatus{{{"populisque}}"}romae', 'Senatus{populisque}}romae'),
        ('{"{literal}"}', '{literal}'),
        ('{"{literal"}', '{literal'),
        ('{"literal}"}', 'literal}'),
        ('{"{{literal}}"}', '{{literal}}'),
        ('{"{{literal"}', '{{literal'),
        ('{"literal}}"}', 'literal}}'),
        ('{{{"literal"}', '{literal'),
        ('{{-{"literal"}', '{-literal'),
        ('{"literal"}}}', 'literal}'),
        ('{"literal"}-}}', 'literal-}'),
        ('{"100"}% {100}% {90+10}% 100% {"%"}1{0}0 %100', '100% 100% 100% 100% %100 %100'),
        ):
        result = avt_expression(arg).evaluate_as_string(DEFAULT_CONTEXT)
        assert isinstance(result, datatypes.string)
        assert result == expected, (result, expected)


def test_avt_errors():
    for arg, in (
        ('{}',),                # no expression is error
        ('{-{{"literal"}',),    # '-{"literal"' is invalid Expr
        ('{"literal"}}-}',),    # '{"literal"} is expr; '}-}' is error
        ('{{node()}',),         # '{{node()' is literal, trailing '}' is error
        ('{node()}}',),         # '{node()}' is expr; trailing '}' is error
        ('(id(@ref)/title}',),  # missing leading '{'
        ('{(id(@ref)/title',),  # missing trailing '{'
        ):
        try:
            avt_expression(arg)
            raise AssertionError("should not have allowed %r" % (arg,))
        except XsltError:
            pass
if __name__ == '__main__':
    raise SystemExit("use nosetests")
